# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`crowdstrike`](#crowdstrike): Simple module installing CrowdStrike's Falcon Agent

## Classes

### <a name="crowdstrike"></a>`crowdstrike`

The module is designed to install, manage and remove CrowdStrike's Falcon Agent antivirus.
Tags and proxy settings can be changed any time using module parameters.

* **See also**
  * https://www.crowdstrike.com/endpoint-security-products/falcon-endpoint-protection-enterprise/

#### Examples

##### Install Falcon Agent and use proxy for connections

```puppet

class { '::crowdstrike':
  ensure             => present,
  cid                => 'AAAAAAAAAAAAAAA-BB',
  provisioning_token => 'XXXXXXXXXXXXXXXXXX',
  tags               => [ 'my_company', 'my_organization' ],
  proxy_host         => 'proxy.mycompany.com',
  proxy_port         => 3128
}
```

#### Parameters

The following parameters are available in the `crowdstrike` class:

* [`ensure`](#ensure)
* [`cid`](#cid)
* [`provisioning_token`](#provisioning_token)
* [`tags`](#tags)
* [`proxy_host`](#proxy_host)
* [`proxy_port`](#proxy_port)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present','absent','latest']`

If `present` or `latest` installs the agent, keeping it up-to-date with the latter value.
When set to `absent` uninstalls the agent's package.

Default value: `'present'`

##### <a name="cid"></a>`cid`

Data type: `Optional[String]`

Customer IDentifier. Necessary to register the agent with the service. Mandatory.

Default value: ``undef``

##### <a name="provisioning_token"></a>`provisioning_token`

Data type: `Optional[String]`

Provisioning token for the crowdstrike agent installation.

Default value: ``undef``

##### <a name="tags"></a>`tags`

Data type: `Optional[Array[String]]`

Array of string tags used to group agents in the CrowdStrike console.

Default value: ``undef``

##### <a name="proxy_host"></a>`proxy_host`

Data type: `Optional[String]`

Proxy server host name for proxied connections. Mandatory if `proxy_port` is specified.

Default value: ``undef``

##### <a name="proxy_port"></a>`proxy_port`

Data type: `Optional[Stdlib::Port]`

Proxy server port for proxied connections. Mandatory if `proxy_host` is specified.

Default value: ``undef``

